#[non_exhaustive]pub struct BatchGetSessionInput {
pub identifiers: Option<Vec<BatchGetSessionIdentifier>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifiers: Option<Vec<BatchGetSessionIdentifier>>The list of session identifiers to retrieve. You can specify up to 100 identifiers per request.
Implementations
Sourceimpl BatchGetSessionInput
impl BatchGetSessionInput
Sourcepub fn identifiers(&self) -> &[BatchGetSessionIdentifier]
pub fn identifiers(&self) -> &[BatchGetSessionIdentifier]
The list of session identifiers to retrieve. You can specify up to 100 identifiers per request.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .identifiers.is_none().
Sourceimpl BatchGetSessionInput
impl BatchGetSessionInput
Sourcepub fn builder() -> BatchGetSessionInputBuilder
pub fn builder() -> BatchGetSessionInputBuilder
Creates a new builder-style object to manufacture BatchGetSessionInput.