#[non_exhaustive]pub struct BatchGetSessionOutput {
pub sessions: Vec<BatchGetSessionItem>,
pub errors: Vec<BatchGetSessionError>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sessions: Vec<BatchGetSessionItem>A list of sessions that were successfully retrieved.
errors: Vec<BatchGetSessionError>A list of errors for sessions that could not be retrieved.
Implementations
Sourceimpl BatchGetSessionOutput
impl BatchGetSessionOutput
Sourcepub fn sessions(&self) -> &[BatchGetSessionItem]
pub fn sessions(&self) -> &[BatchGetSessionItem]
A list of sessions that were successfully retrieved.
Sourcepub fn errors(&self) -> &[BatchGetSessionError]
pub fn errors(&self) -> &[BatchGetSessionError]
A list of errors for sessions that could not be retrieved.
Sourceimpl BatchGetSessionOutput
impl BatchGetSessionOutput
Sourcepub fn builder() -> BatchGetSessionOutputBuilder
pub fn builder() -> BatchGetSessionOutputBuilder
Creates a new builder-style object to manufacture BatchGetSessionOutput.