#[non_exhaustive]pub struct BatchGetStepOutput {
pub steps: Vec<BatchGetStepItem>,
pub errors: Vec<BatchGetStepError>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.steps: Vec<BatchGetStepItem>A list of steps that were successfully retrieved.
errors: Vec<BatchGetStepError>A list of errors for steps that could not be retrieved.
Implementations
Sourceimpl BatchGetStepOutput
impl BatchGetStepOutput
Sourcepub fn steps(&self) -> &[BatchGetStepItem]
pub fn steps(&self) -> &[BatchGetStepItem]
A list of steps that were successfully retrieved.
Sourcepub fn errors(&self) -> &[BatchGetStepError]
pub fn errors(&self) -> &[BatchGetStepError]
A list of errors for steps that could not be retrieved.
Sourceimpl BatchGetStepOutput
impl BatchGetStepOutput
Sourcepub fn builder() -> BatchGetStepOutputBuilder
pub fn builder() -> BatchGetStepOutputBuilder
Creates a new builder-style object to manufacture BatchGetStepOutput.