#[non_exhaustive]pub struct BatchGetTaskInputBuilder { /* private fields */ }Expand description
A builder for BatchGetTaskInput.
Implementations
Sourceimpl BatchGetTaskInputBuilder
impl BatchGetTaskInputBuilder
Sourcepub fn identifiers(self, input: BatchGetTaskIdentifier) -> Self
pub fn identifiers(self, input: BatchGetTaskIdentifier) -> Self
Appends an item to identifiers.
To override the contents of this collection use set_identifiers.
The list of task identifiers to retrieve. You can specify up to 100 identifiers per request.
Sourcepub fn set_identifiers(self, input: Option<Vec<BatchGetTaskIdentifier>>) -> Self
pub fn set_identifiers(self, input: Option<Vec<BatchGetTaskIdentifier>>) -> Self
The list of task identifiers to retrieve. You can specify up to 100 identifiers per request.
Sourcepub fn get_identifiers(&self) -> &Option<Vec<BatchGetTaskIdentifier>>
pub fn get_identifiers(&self) -> &Option<Vec<BatchGetTaskIdentifier>>
The list of task identifiers to retrieve. You can specify up to 100 identifiers per request.
Sourcepub fn build(self) -> Result<BatchGetTaskInput, BuildError>
pub fn build(self) -> Result<BatchGetTaskInput, BuildError>
Consumes the builder and constructs a BatchGetTaskInput.
Sourceimpl BatchGetTaskInputBuilder
impl BatchGetTaskInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchGetTaskOutput, SdkError<BatchGetTaskError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchGetTaskOutput, SdkError<BatchGetTaskError, HttpResponse>>
Sends a request with this input using the given client.