#[non_exhaustive]pub struct BatchUpdateTaskInputBuilder { /* private fields */ }Expand description
A builder for BatchUpdateTaskInput.
Implementations
Sourceimpl BatchUpdateTaskInputBuilder
impl BatchUpdateTaskInputBuilder
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
The unique token which the server uses to recognize retries of the same request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
The unique token which the server uses to recognize retries of the same request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
The unique token which the server uses to recognize retries of the same request.
Sourcepub fn tasks(self, input: BatchUpdateTaskItem) -> Self
pub fn tasks(self, input: BatchUpdateTaskItem) -> Self
Appends an item to tasks.
To override the contents of this collection use set_tasks.
The list of tasks to update. You can specify up to 100 tasks per request.
Sourcepub fn set_tasks(self, input: Option<Vec<BatchUpdateTaskItem>>) -> Self
pub fn set_tasks(self, input: Option<Vec<BatchUpdateTaskItem>>) -> Self
The list of tasks to update. You can specify up to 100 tasks per request.
Sourcepub fn get_tasks(&self) -> &Option<Vec<BatchUpdateTaskItem>>
pub fn get_tasks(&self) -> &Option<Vec<BatchUpdateTaskItem>>
The list of tasks to update. You can specify up to 100 tasks per request.
Sourcepub fn build(self) -> Result<BatchUpdateTaskInput, BuildError>
pub fn build(self) -> Result<BatchUpdateTaskInput, BuildError>
Consumes the builder and constructs a BatchUpdateTaskInput.
Sourceimpl BatchUpdateTaskInputBuilder
impl BatchUpdateTaskInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchUpdateTaskOutput, SdkError<BatchUpdateTaskError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchUpdateTaskOutput, SdkError<BatchUpdateTaskError, HttpResponse>>
Sends a request with this input using the given client.