#[non_exhaustive]pub struct BatchUpdateTaskInput {
pub client_token: Option<String>,
pub tasks: Option<Vec<BatchUpdateTaskItem>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>The unique token which the server uses to recognize retries of the same request.
tasks: Option<Vec<BatchUpdateTaskItem>>The list of tasks to update. You can specify up to 100 tasks per request.
Implementations
Sourceimpl BatchUpdateTaskInput
impl BatchUpdateTaskInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
The unique token which the server uses to recognize retries of the same request.
Sourcepub fn tasks(&self) -> &[BatchUpdateTaskItem]
pub fn tasks(&self) -> &[BatchUpdateTaskItem]
The list of tasks to update. You can specify up to 100 tasks per request.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tasks.is_none().
Sourceimpl BatchUpdateTaskInput
impl BatchUpdateTaskInput
Sourcepub fn builder() -> BatchUpdateTaskInputBuilder
pub fn builder() -> BatchUpdateTaskInputBuilder
Creates a new builder-style object to manufacture BatchUpdateTaskInput.