#[non_exhaustive]pub struct BatchUpdateTaskItemBuilder { /* private fields */ }Expand description
A builder for BatchUpdateTaskItem.
Implementations
Sourceimpl BatchUpdateTaskItemBuilder
impl BatchUpdateTaskItemBuilder
Sourcepub fn farm_id(self, input: impl Into<String>) -> Self
pub fn farm_id(self, input: impl Into<String>) -> Self
The farm ID of the task to update.
This field is required.Sourcepub fn set_farm_id(self, input: Option<String>) -> Self
pub fn set_farm_id(self, input: Option<String>) -> Self
The farm ID of the task to update.
Sourcepub fn get_farm_id(&self) -> &Option<String>
pub fn get_farm_id(&self) -> &Option<String>
The farm ID of the task to update.
Sourcepub fn queue_id(self, input: impl Into<String>) -> Self
pub fn queue_id(self, input: impl Into<String>) -> Self
The queue ID of the task to update.
This field is required.Sourcepub fn set_queue_id(self, input: Option<String>) -> Self
pub fn set_queue_id(self, input: Option<String>) -> Self
The queue ID of the task to update.
Sourcepub fn get_queue_id(&self) -> &Option<String>
pub fn get_queue_id(&self) -> &Option<String>
The queue ID of the task to update.
Sourcepub fn job_id(self, input: impl Into<String>) -> Self
pub fn job_id(self, input: impl Into<String>) -> Self
The job ID of the task to update.
This field is required.Sourcepub fn set_job_id(self, input: Option<String>) -> Self
pub fn set_job_id(self, input: Option<String>) -> Self
The job ID of the task to update.
Sourcepub fn get_job_id(&self) -> &Option<String>
pub fn get_job_id(&self) -> &Option<String>
The job ID of the task to update.
Sourcepub fn step_id(self, input: impl Into<String>) -> Self
pub fn step_id(self, input: impl Into<String>) -> Self
The step ID of the task to update.
This field is required.Sourcepub fn set_step_id(self, input: Option<String>) -> Self
pub fn set_step_id(self, input: Option<String>) -> Self
The step ID of the task to update.
Sourcepub fn get_step_id(&self) -> &Option<String>
pub fn get_step_id(&self) -> &Option<String>
The step ID of the task to update.
Sourcepub fn task_id(self, input: impl Into<String>) -> Self
pub fn task_id(self, input: impl Into<String>) -> Self
The task ID of the task to update.
This field is required.Sourcepub fn set_task_id(self, input: Option<String>) -> Self
pub fn set_task_id(self, input: Option<String>) -> Self
The task ID of the task to update.
Sourcepub fn get_task_id(&self) -> &Option<String>
pub fn get_task_id(&self) -> &Option<String>
The task ID of the task to update.
Sourcepub fn target_run_status(self, input: TaskTargetRunStatus) -> Self
pub fn target_run_status(self, input: TaskTargetRunStatus) -> Self
The run status with which to start the task.
This field is required.Sourcepub fn set_target_run_status(self, input: Option<TaskTargetRunStatus>) -> Self
pub fn set_target_run_status(self, input: Option<TaskTargetRunStatus>) -> Self
The run status with which to start the task.
Sourcepub fn get_target_run_status(&self) -> &Option<TaskTargetRunStatus>
pub fn get_target_run_status(&self) -> &Option<TaskTargetRunStatus>
The run status with which to start the task.
Sourcepub fn build(self) -> Result<BatchUpdateTaskItem, BuildError>
pub fn build(self) -> Result<BatchUpdateTaskItem, BuildError>
Consumes the builder and constructs a BatchUpdateTaskItem.
This method will fail if any of the following fields are not set: