#[non_exhaustive]pub struct ServiceManagedEc2AutoScalingConfigurationBuilder { /* private fields */ }Expand description
A builder for ServiceManagedEc2AutoScalingConfiguration.
Implementations
Sourceimpl ServiceManagedEc2AutoScalingConfigurationBuilder
impl ServiceManagedEc2AutoScalingConfigurationBuilder
Sourcepub fn standby_worker_count(self, input: i32) -> Self
pub fn standby_worker_count(self, input: i32) -> Self
The number of idle workers maintained and ready to process incoming tasks. The default is 0.
Sourcepub fn set_standby_worker_count(self, input: Option<i32>) -> Self
pub fn set_standby_worker_count(self, input: Option<i32>) -> Self
The number of idle workers maintained and ready to process incoming tasks. The default is 0.
Sourcepub fn get_standby_worker_count(&self) -> &Option<i32>
pub fn get_standby_worker_count(&self) -> &Option<i32>
The number of idle workers maintained and ready to process incoming tasks. The default is 0.
Sourcepub fn worker_idle_duration_seconds(self, input: i32) -> Self
pub fn worker_idle_duration_seconds(self, input: i32) -> Self
The number of seconds that a worker can remain idle before it is shut down. The default is 300 seconds (5 minutes).
Sourcepub fn set_worker_idle_duration_seconds(self, input: Option<i32>) -> Self
pub fn set_worker_idle_duration_seconds(self, input: Option<i32>) -> Self
The number of seconds that a worker can remain idle before it is shut down. The default is 300 seconds (5 minutes).
Sourcepub fn get_worker_idle_duration_seconds(&self) -> &Option<i32>
pub fn get_worker_idle_duration_seconds(&self) -> &Option<i32>
The number of seconds that a worker can remain idle before it is shut down. The default is 300 seconds (5 minutes).
Sourcepub fn scale_out_workers_per_minute(self, input: i32) -> Self
pub fn scale_out_workers_per_minute(self, input: i32) -> Self
The number of workers that can be added per minute to the fleet. The default is 10 workers per minute.
Sourcepub fn set_scale_out_workers_per_minute(self, input: Option<i32>) -> Self
pub fn set_scale_out_workers_per_minute(self, input: Option<i32>) -> Self
The number of workers that can be added per minute to the fleet. The default is 10 workers per minute.
Sourcepub fn get_scale_out_workers_per_minute(&self) -> &Option<i32>
pub fn get_scale_out_workers_per_minute(&self) -> &Option<i32>
The number of workers that can be added per minute to the fleet. The default is 10 workers per minute.
Sourcepub fn build(self) -> ServiceManagedEc2AutoScalingConfiguration
pub fn build(self) -> ServiceManagedEc2AutoScalingConfiguration
Consumes the builder and constructs a ServiceManagedEc2AutoScalingConfiguration.