#[non_exhaustive]pub struct BatchGetSessionError {
pub farm_id: String,
pub queue_id: String,
pub job_id: String,
pub session_id: String,
pub code: BatchGetSessionErrorCode,
pub message: String,
}Expand description
The error details for a session that could not be retrieved in a batch get operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.farm_id: StringThe farm ID of the session that could not be retrieved.
queue_id: StringThe queue ID of the session that could not be retrieved.
job_id: StringThe job ID of the session that could not be retrieved.
session_id: StringThe session ID of the session that could not be retrieved.
code: BatchGetSessionErrorCodeThe error code.
message: StringThe error message.
Implementations
Sourceimpl BatchGetSessionError
impl BatchGetSessionError
Sourcepub fn session_id(&self) -> &str
pub fn session_id(&self) -> &str
The session ID of the session that could not be retrieved.
Sourcepub fn code(&self) -> &BatchGetSessionErrorCode
pub fn code(&self) -> &BatchGetSessionErrorCode
The error code.
Sourceimpl BatchGetSessionError
impl BatchGetSessionError
Sourcepub fn builder() -> BatchGetSessionErrorBuilder
pub fn builder() -> BatchGetSessionErrorBuilder
Creates a new builder-style object to manufacture BatchGetSessionError.