#[non_exhaustive]pub struct BatchGetStepItem {Show 21 fields
pub farm_id: String,
pub queue_id: String,
pub job_id: String,
pub step_id: String,
pub name: String,
pub lifecycle_status: StepLifecycleStatus,
pub lifecycle_status_message: Option<String>,
pub task_run_status: TaskRunStatus,
pub task_run_status_counts: HashMap<TaskRunStatus, i32>,
pub task_failure_retry_count: Option<i32>,
pub target_task_run_status: Option<StepTargetTaskRunStatus>,
pub created_at: DateTime,
pub created_by: String,
pub updated_at: Option<DateTime>,
pub updated_by: Option<String>,
pub started_at: Option<DateTime>,
pub ended_at: Option<DateTime>,
pub dependency_counts: Option<DependencyCounts>,
pub required_capabilities: Option<StepRequiredCapabilities>,
pub parameter_space: Option<ParameterSpace>,
pub description: Option<String>,
}Expand description
The details of a step returned in a batch get operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.farm_id: StringThe farm ID of the step.
queue_id: StringThe queue ID of the step.
job_id: StringThe job ID of the step.
step_id: StringThe step ID.
name: StringThe name of the step.
lifecycle_status: StepLifecycleStatusThe life cycle status of the step.
lifecycle_status_message: Option<String>A message that communicates the status of the life cycle.
task_run_status: TaskRunStatusThe task run status for the step.
task_run_status_counts: HashMap<TaskRunStatus, i32>The number of tasks for each run status for the step.
task_failure_retry_count: Option<i32>The number of times that tasks failed and were retried.
target_task_run_status: Option<StepTargetTaskRunStatus>The task status to start with on the step.
created_at: DateTimeThe date and time the resource was created.
created_by: StringThe user or system that created this resource.
updated_at: Option<DateTime>The date and time the resource was updated.
updated_by: Option<String>The user or system that updated this resource.
started_at: Option<DateTime>The date and time the resource started running.
ended_at: Option<DateTime>The date and time the resource ended running.
dependency_counts: Option<DependencyCounts>The number of dependencies for the step.
required_capabilities: Option<StepRequiredCapabilities>The required capabilities for the step.
parameter_space: Option<ParameterSpace>The parameter space for the step.
description: Option<String>The description of the step.
Implementations
Sourceimpl BatchGetStepItem
impl BatchGetStepItem
Sourcepub fn lifecycle_status(&self) -> &StepLifecycleStatus
pub fn lifecycle_status(&self) -> &StepLifecycleStatus
The life cycle status of the step.
Sourcepub fn lifecycle_status_message(&self) -> Option<&str>
pub fn lifecycle_status_message(&self) -> Option<&str>
A message that communicates the status of the life cycle.
Sourcepub fn task_run_status(&self) -> &TaskRunStatus
pub fn task_run_status(&self) -> &TaskRunStatus
The task run status for the step.
Sourcepub fn task_run_status_counts(&self) -> &HashMap<TaskRunStatus, i32>
pub fn task_run_status_counts(&self) -> &HashMap<TaskRunStatus, i32>
The number of tasks for each run status for the step.
Sourcepub fn task_failure_retry_count(&self) -> Option<i32>
pub fn task_failure_retry_count(&self) -> Option<i32>
The number of times that tasks failed and were retried.
Sourcepub fn target_task_run_status(&self) -> Option<&StepTargetTaskRunStatus>
pub fn target_task_run_status(&self) -> Option<&StepTargetTaskRunStatus>
The task status to start with on the step.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The date and time the resource was created.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
The user or system that created this resource.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the resource was updated.
Sourcepub fn updated_by(&self) -> Option<&str>
pub fn updated_by(&self) -> Option<&str>
The user or system that updated this resource.
Sourcepub fn started_at(&self) -> Option<&DateTime>
pub fn started_at(&self) -> Option<&DateTime>
The date and time the resource started running.
Sourcepub fn dependency_counts(&self) -> Option<&DependencyCounts>
pub fn dependency_counts(&self) -> Option<&DependencyCounts>
The number of dependencies for the step.
Sourcepub fn required_capabilities(&self) -> Option<&StepRequiredCapabilities>
pub fn required_capabilities(&self) -> Option<&StepRequiredCapabilities>
The required capabilities for the step.
Sourcepub fn parameter_space(&self) -> Option<&ParameterSpace>
pub fn parameter_space(&self) -> Option<&ParameterSpace>
The parameter space for the step.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the step.
Sourceimpl BatchGetStepItem
impl BatchGetStepItem
Sourcepub fn builder() -> BatchGetStepItemBuilder
pub fn builder() -> BatchGetStepItemBuilder
Creates a new builder-style object to manufacture BatchGetStepItem.