#[non_exhaustive]pub struct BatchGetTaskError {
pub farm_id: String,
pub queue_id: String,
pub job_id: String,
pub step_id: String,
pub task_id: String,
pub code: BatchGetTaskErrorCode,
pub message: String,
}Expand description
The error details for a task that could not be retrieved in a batch get operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.farm_id: StringThe farm ID of the task that could not be retrieved.
queue_id: StringThe queue ID of the task that could not be retrieved.
job_id: StringThe job ID of the task that could not be retrieved.
step_id: StringThe step ID of the task that could not be retrieved.
task_id: StringThe task ID of the task that could not be retrieved.
code: BatchGetTaskErrorCodeThe error code.
message: StringThe error message.
Implementations
Sourceimpl BatchGetTaskError
impl BatchGetTaskError
Sourcepub fn code(&self) -> &BatchGetTaskErrorCode
pub fn code(&self) -> &BatchGetTaskErrorCode
The error code.
Sourceimpl BatchGetTaskError
impl BatchGetTaskError
Sourcepub fn builder() -> BatchGetTaskErrorBuilder
pub fn builder() -> BatchGetTaskErrorBuilder
Creates a new builder-style object to manufacture BatchGetTaskError.