#[non_exhaustive]pub struct BatchGetTaskItem {Show 16 fields
pub farm_id: String,
pub queue_id: String,
pub job_id: String,
pub step_id: String,
pub task_id: String,
pub created_at: DateTime,
pub created_by: String,
pub run_status: TaskRunStatus,
pub target_run_status: Option<TaskTargetRunStatus>,
pub failure_retry_count: Option<i32>,
pub started_at: Option<DateTime>,
pub ended_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub updated_by: Option<String>,
pub latest_session_action_id: Option<String>,
pub parameters: Option<HashMap<String, TaskParameterValue>>,
}Expand description
The details of a task returned in a batch get operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.farm_id: StringThe farm ID of the task.
queue_id: StringThe queue ID of the task.
job_id: StringThe job ID of the task.
step_id: StringThe step ID of the task.
task_id: StringThe task ID.
created_at: DateTimeThe date and time the resource was created.
created_by: StringThe user or system that created this resource.
run_status: TaskRunStatusThe run status of the task.
target_run_status: Option<TaskTargetRunStatus>The run status with which to start the task.
failure_retry_count: Option<i32>The number of times the task failed and was retried.
started_at: Option<DateTime>The date and time the resource started running.
ended_at: Option<DateTime>The date and time the resource ended running.
updated_at: Option<DateTime>The date and time the resource was updated.
updated_by: Option<String>The user or system that updated this resource.
latest_session_action_id: Option<String>The latest session action for the task.
parameters: Option<HashMap<String, TaskParameterValue>>The parameters for the task.
Implementations
Sourceimpl BatchGetTaskItem
impl BatchGetTaskItem
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The date and time the resource was created.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
The user or system that created this resource.
Sourcepub fn run_status(&self) -> &TaskRunStatus
pub fn run_status(&self) -> &TaskRunStatus
The run status of the task.
Sourcepub fn target_run_status(&self) -> Option<&TaskTargetRunStatus>
pub fn target_run_status(&self) -> Option<&TaskTargetRunStatus>
The run status with which to start the task.
Sourcepub fn failure_retry_count(&self) -> Option<i32>
pub fn failure_retry_count(&self) -> Option<i32>
The number of times the task failed and was retried.
Sourcepub fn started_at(&self) -> Option<&DateTime>
pub fn started_at(&self) -> Option<&DateTime>
The date and time the resource started running.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The date and time the resource was updated.
Sourcepub fn updated_by(&self) -> Option<&str>
pub fn updated_by(&self) -> Option<&str>
The user or system that updated this resource.
Sourcepub fn latest_session_action_id(&self) -> Option<&str>
pub fn latest_session_action_id(&self) -> Option<&str>
The latest session action for the task.
Sourcepub fn parameters(&self) -> Option<&HashMap<String, TaskParameterValue>>
pub fn parameters(&self) -> Option<&HashMap<String, TaskParameterValue>>
The parameters for the task.
Sourceimpl BatchGetTaskItem
impl BatchGetTaskItem
Sourcepub fn builder() -> BatchGetTaskItemBuilder
pub fn builder() -> BatchGetTaskItemBuilder
Creates a new builder-style object to manufacture BatchGetTaskItem.