#[non_exhaustive]pub struct BatchUpdateJobItem {
pub farm_id: String,
pub queue_id: String,
pub job_id: String,
pub target_task_run_status: Option<JobTargetTaskRunStatus>,
pub priority: Option<i32>,
pub max_failed_tasks_count: Option<i32>,
pub max_retries_per_task: Option<i32>,
pub lifecycle_status: Option<UpdateJobLifecycleStatus>,
pub max_worker_count: Option<i32>,
pub name: Option<String>,
pub description: Option<String>,
}Expand description
The details of a job to update in a batch update operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.farm_id: StringThe farm ID of the job to update.
queue_id: StringThe queue ID of the job to update.
job_id: StringThe job ID of the job to update.
target_task_run_status: Option<JobTargetTaskRunStatus>The task status to update the job's tasks to.
priority: Option<i32>The job priority to update.
max_failed_tasks_count: Option<i32>The number of task failures before the job stops running and is marked as FAILED.
max_retries_per_task: Option<i32>The maximum number of retries per failed tasks.
lifecycle_status: Option<UpdateJobLifecycleStatus>The status of a job in its lifecycle. When you change the status of the job to ARCHIVED, the job can't be scheduled or archived.
An archived job and its steps and tasks are deleted after 120 days. The job can't be recovered.
max_worker_count: Option<i32>The maximum number of worker hosts that can concurrently process a job.
name: Option<String>The name of the job to update.
description: Option<String>The description of the job to update.
Implementations
Sourceimpl BatchUpdateJobItem
impl BatchUpdateJobItem
Sourcepub fn target_task_run_status(&self) -> Option<&JobTargetTaskRunStatus>
pub fn target_task_run_status(&self) -> Option<&JobTargetTaskRunStatus>
The task status to update the job's tasks to.
Sourcepub fn max_failed_tasks_count(&self) -> Option<i32>
pub fn max_failed_tasks_count(&self) -> Option<i32>
The number of task failures before the job stops running and is marked as FAILED.
Sourcepub fn max_retries_per_task(&self) -> Option<i32>
pub fn max_retries_per_task(&self) -> Option<i32>
The maximum number of retries per failed tasks.
Sourcepub fn lifecycle_status(&self) -> Option<&UpdateJobLifecycleStatus>
pub fn lifecycle_status(&self) -> Option<&UpdateJobLifecycleStatus>
The status of a job in its lifecycle. When you change the status of the job to ARCHIVED, the job can't be scheduled or archived.
An archived job and its steps and tasks are deleted after 120 days. The job can't be recovered.
Sourcepub fn max_worker_count(&self) -> Option<i32>
pub fn max_worker_count(&self) -> Option<i32>
The maximum number of worker hosts that can concurrently process a job.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the job to update.
Sourceimpl BatchUpdateJobItem
impl BatchUpdateJobItem
Sourcepub fn builder() -> BatchUpdateJobItemBuilder
pub fn builder() -> BatchUpdateJobItemBuilder
Creates a new builder-style object to manufacture BatchUpdateJobItem.