#[non_exhaustive]pub struct BatchUpdateTaskError {
pub farm_id: String,
pub queue_id: String,
pub job_id: String,
pub step_id: String,
pub task_id: String,
pub code: BatchUpdateTaskErrorCode,
pub message: String,
}Expand description
The error details for a task that could not be updated in a batch update operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.farm_id: StringThe farm ID of the task that could not be updated.
queue_id: StringThe queue ID of the task that could not be updated.
job_id: StringThe job ID of the task that could not be updated.
step_id: StringThe step ID of the task that could not be updated.
task_id: StringThe task ID of the task that could not be updated.
code: BatchUpdateTaskErrorCodeThe error code.
message: StringThe error message.
Implementations
Sourceimpl BatchUpdateTaskError
impl BatchUpdateTaskError
Sourcepub fn code(&self) -> &BatchUpdateTaskErrorCode
pub fn code(&self) -> &BatchUpdateTaskErrorCode
The error code.
Sourceimpl BatchUpdateTaskError
impl BatchUpdateTaskError
Sourcepub fn builder() -> BatchUpdateTaskErrorBuilder
pub fn builder() -> BatchUpdateTaskErrorBuilder
Creates a new builder-style object to manufacture BatchUpdateTaskError.