#[non_exhaustive]pub struct BatchUpdateTaskItem {
pub farm_id: String,
pub queue_id: String,
pub job_id: String,
pub step_id: String,
pub task_id: String,
pub target_run_status: TaskTargetRunStatus,
}Expand description
The details of a task to update in a batch update operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.farm_id: StringThe farm ID of the task to update.
queue_id: StringThe queue ID of the task to update.
job_id: StringThe job ID of the task to update.
step_id: StringThe step ID of the task to update.
task_id: StringThe task ID of the task to update.
target_run_status: TaskTargetRunStatusThe run status with which to start the task.
Implementations
Sourceimpl BatchUpdateTaskItem
impl BatchUpdateTaskItem
Sourcepub fn target_run_status(&self) -> &TaskTargetRunStatus
pub fn target_run_status(&self) -> &TaskTargetRunStatus
The run status with which to start the task.
Sourceimpl BatchUpdateTaskItem
impl BatchUpdateTaskItem
Sourcepub fn builder() -> BatchUpdateTaskItemBuilder
pub fn builder() -> BatchUpdateTaskItemBuilder
Creates a new builder-style object to manufacture BatchUpdateTaskItem.