#[non_exhaustive]pub struct PriorityBalancedSchedulingConfiguration {
pub rendering_task_buffer: i32,
}Expand description
Configuration for priority balanced scheduling. Workers are distributed evenly across all jobs at the highest priority level.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rendering_task_buffer: i32The rendering task buffer controls worker stickiness. A worker only switches from its current job to another job at the same priority if the other job has fewer rendering tasks by more than this buffer value. Higher values make workers stickier to their current jobs. The default value is 1.
Implementations
Sourceimpl PriorityBalancedSchedulingConfiguration
impl PriorityBalancedSchedulingConfiguration
Sourcepub fn rendering_task_buffer(&self) -> i32
pub fn rendering_task_buffer(&self) -> i32
The rendering task buffer controls worker stickiness. A worker only switches from its current job to another job at the same priority if the other job has fewer rendering tasks by more than this buffer value. Higher values make workers stickier to their current jobs. The default value is 1.
Sourceimpl PriorityBalancedSchedulingConfiguration
impl PriorityBalancedSchedulingConfiguration
Sourcepub fn builder() -> PriorityBalancedSchedulingConfigurationBuilder
pub fn builder() -> PriorityBalancedSchedulingConfigurationBuilder
Creates a new builder-style object to manufacture PriorityBalancedSchedulingConfiguration.