#[non_exhaustive]pub struct ServiceManagedEc2AutoScalingConfiguration {
pub standby_worker_count: Option<i32>,
pub worker_idle_duration_seconds: i32,
pub scale_out_workers_per_minute: Option<i32>,
}Expand description
The auto scaling configuration settings for a service managed EC2 fleet.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.standby_worker_count: Option<i32>The number of idle workers maintained and ready to process incoming tasks. The default is 0.
worker_idle_duration_seconds: i32The number of seconds that a worker can remain idle before it is shut down. The default is 300 seconds (5 minutes).
scale_out_workers_per_minute: Option<i32>The number of workers that can be added per minute to the fleet. The default is 10 workers per minute.
Implementations
Sourceimpl ServiceManagedEc2AutoScalingConfiguration
impl ServiceManagedEc2AutoScalingConfiguration
Sourcepub fn standby_worker_count(&self) -> Option<i32>
pub fn standby_worker_count(&self) -> Option<i32>
The number of idle workers maintained and ready to process incoming tasks. The default is 0.
Sourcepub fn worker_idle_duration_seconds(&self) -> i32
pub fn worker_idle_duration_seconds(&self) -> i32
The number of seconds that a worker can remain idle before it is shut down. The default is 300 seconds (5 minutes).
Sourcepub fn scale_out_workers_per_minute(&self) -> Option<i32>
pub fn scale_out_workers_per_minute(&self) -> Option<i32>
The number of workers that can be added per minute to the fleet. The default is 10 workers per minute.
Sourceimpl ServiceManagedEc2AutoScalingConfiguration
impl ServiceManagedEc2AutoScalingConfiguration
Sourcepub fn builder() -> ServiceManagedEc2AutoScalingConfigurationBuilder
pub fn builder() -> ServiceManagedEc2AutoScalingConfigurationBuilder
Creates a new builder-style object to manufacture ServiceManagedEc2AutoScalingConfiguration.