#[non_exhaustive]pub struct StepParameterChunks {
pub default_task_count: i32,
pub target_runtime_seconds: Option<i32>,
pub range_constraint: RangeConstraint,
}Expand description
Defines how a step parameter range should be divided into chunks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default_task_count: i32The number of tasks to combine into a single chunk by default.
target_runtime_seconds: Option<i32>The number of seconds to aim for when forming chunks.
range_constraint: RangeConstraintSpecifies whether the chunked ranges must be contiguous or can have gaps between them.
Implementations
Sourceimpl StepParameterChunks
impl StepParameterChunks
Sourcepub fn default_task_count(&self) -> i32
pub fn default_task_count(&self) -> i32
The number of tasks to combine into a single chunk by default.
Sourcepub fn target_runtime_seconds(&self) -> Option<i32>
pub fn target_runtime_seconds(&self) -> Option<i32>
The number of seconds to aim for when forming chunks.
Sourcepub fn range_constraint(&self) -> &RangeConstraint
pub fn range_constraint(&self) -> &RangeConstraint
Specifies whether the chunked ranges must be contiguous or can have gaps between them.
Sourceimpl StepParameterChunks
impl StepParameterChunks
Sourcepub fn builder() -> StepParameterChunksBuilder
pub fn builder() -> StepParameterChunksBuilder
Creates a new builder-style object to manufacture StepParameterChunks.